# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassHunter.Quantitative.UIModel

class CompoundGroupFilterInfo(
    System.IComparable[Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo]
):  # Struct
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType,
        compoundGroup: str,
    ) -> None: ...

    CompoundGroup: str
    Type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self, info: Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo
    ) -> bool: ...
    @overload
    def Matches(
        self, key: Agilent.MassHunter.Quantitative.UIModel.CompoundKey
    ) -> bool: ...
    @overload
    def Matches(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> bool: ...
    def GetHashCode(self) -> int: ...
    def CompareTo(
        self, other: Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo
    ) -> int: ...
    def ToString(self) -> str: ...

class CompoundKey(
    System.IComparable[Agilent.MassHunter.Quantitative.UIModel.CompoundKey]
):  # Struct
    def __init__(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> None: ...

    CompoundGroup: str  # readonly
    CompoundId: int  # readonly
    CompoundName: str  # readonly
    Empty: Agilent.MassHunter.Quantitative.UIModel.CompoundKey  # static # readonly
    ID: Optional[int]  # readonly
    IstdCompoundId: Optional[int]  # readonly
    IstdRetentionTime: Optional[float]  # readonly
    Mz: Optional[float]  # readonly
    RetentionTime: Optional[float]  # readonly
    SelectedMz: Optional[float]  # readonly
    TimeSegment: Optional[int]  # readonly
    UserDefined: str  # readonly

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self, ck: Agilent.MassHunter.Quantitative.UIModel.CompoundKey
    ) -> bool: ...
    def Matches(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> bool: ...
    @staticmethod
    def Compare(
        k1: Agilent.MassHunter.Quantitative.UIModel.CompoundKey,
        k2: Agilent.MassHunter.Quantitative.UIModel.CompoundKey,
    ) -> int: ...
    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...

class ICagWindow(System.Windows.Forms.IWin32Window):  # Interface
    ContainsFocus: bool  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    Height: int
    IsHandleCreated: bool  # readonly
    Location: System.Drawing.Point
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    Visible: bool  # readonly
    Width: int
    WindowState: System.Windows.Forms.FormWindowState

    def Show(self) -> None: ...
    def ShowHelpContents(self) -> None: ...
    def ShowHelpSearch(self) -> None: ...
    def GetAddInManager(self) -> T: ...
    def ShowSetupGraphicsDialog(self) -> None: ...
    def ShowHelpIndex(self) -> None: ...
    def GetSelectedCompounds(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    ]: ...
    def GetSelectedSamples(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleRowId]: ...
    def GetChromatogramControl(self) -> T: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def SetCurrentLayoutAsDefault(self) -> None: ...
    def Close(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def Activate(self) -> None: ...
    def GetSetupGraphicsContext(self) -> T: ...
    def GetToolbar(
        self, paneId: str, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar: ...
    def Invoke(self, d: System.Delegate, parameters: List[Any]) -> Any: ...
    def LoadDefaultLayout(self, loadAllSamplesCompounds: bool) -> bool: ...

    Disposed: System.EventHandler  # Event

class ICalCurvePane(System.Windows.Forms.IWin32Window):  # Interface
    AutoScale: bool
    CanAcceptAssistantCurve: bool  # readonly
    CanAutoScale: bool  # readonly
    CanCopy: bool  # readonly
    CurveFitAssistantConfidenceBandVisible: bool
    CurveFitAssistantTable: (
        Agilent.MassHunter.Quantitative.UIModel.IGridControl
    )  # readonly
    CurveFitAssistantVisible: bool  # readonly
    IsLogScaleX: bool
    IsLogScaleY: bool
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    RelativeConcentration: bool
    ShowCC: bool
    ShowIstdResponses: bool
    ShowQC: bool
    ShowStandardDeviationBars: bool

    def AcceptAssistantCurve(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def Copy(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def StoreSettings(self) -> None: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def HideCurveFitAssistant(self) -> None: ...
    def FitToLevels(self, levelNames: Iterable[str], includesOrigin: bool) -> None: ...
    def ShowCurveFitAssistant(self) -> None: ...

class ICalibrationAtAGlanceWindow(System.Windows.Forms.IWin32Window):  # Interface
    ContainsFocus: bool  # readonly
    Height: int
    Location: System.Drawing.Point
    NumColumnsPerPage: int  # readonly
    NumRowsPerPage: int  # readonly
    Visible: bool  # readonly
    Width: int
    WindowState: System.Windows.Forms.FormWindowState

    def GetSelectedTargetCompounds(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    ]: ...
    def Close(self) -> None: ...
    def Show(self) -> None: ...
    def SetDimension(self, rows: int, columns: int) -> None: ...
    def Activate(self) -> None: ...

    Closed: System.EventHandler  # Event

class IChromSpecPane(System.Windows.Forms.IWin32Window):  # Interface
    AutoScale: bool
    CanAutoScale: bool  # readonly
    CanClearManualIntegration: bool  # readonly
    CanCopy: bool  # readonly
    CanFitToCalibrationLevel: bool  # readonly
    CanFitToPeak: bool  # readonly
    CanFitToPeakHeight: bool  # readonly
    CanManualIntegrate: bool  # readonly
    CanResetRTRange: bool  # readonly
    CanRestoreIntegrationSetup: bool  # readonly
    CanSearchLibrary: bool  # readonly
    CanShowDeconvolutedComponents: bool  # readonly
    CanShowIntegrationSetupDialog: bool  # readonly
    CanShowWiderRTRange: bool  # readonly
    CanZeroPeak: bool  # readonly
    ChromatogramXUnit: Agilent.MassSpectrometry.DataAnalysis.DataUnit
    FillPeaks: bool
    FitToHighestLevel: bool
    FitToLowestLevel: bool
    FitToPeak: bool
    FitToPeakHeight: bool
    IsSelectedPaneCompound: bool  # readonly
    IsSelectedPaneIstd: bool  # readonly
    IsSelectedPaneQualifier: bool  # readonly
    IsSelectedPaneSpectrum: bool  # readonly
    ManualIntegrationMode: bool  # readonly
    ManualScaleY: bool  # readonly
    NormalizeQualifiers: bool
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    Properties: Agilent.MassHunter.Quantitative.UIModel.IChromSpecProperties  # readonly
    SelectedCompoundId: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    )  # readonly
    SelectedQualifierId: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetQualifierRowId
    )  # readonly
    ShowBaselineCalculationPoints: bool
    ShowBaselines: bool
    ShowChromatogram: bool
    ShowDeconvolutedComponents: bool
    ShowIstd: bool
    ShowMatchScores: bool
    ShowOverrideSpectrum: bool
    ShowQualifierAnnotations: bool
    ShowQualifiers: bool
    ShowReferenceSpectrum: bool
    ShowSpectrum: bool
    ShowUncertaintyBand: bool

    def GetActiveObject(self) -> T: ...
    def AutoScaleY(self) -> None: ...
    def RestoreIntegrationSetup(self) -> None: ...
    def SetManualScaleY(self, miny: float, maxy: float) -> None: ...
    def Copy(self) -> None: ...
    def SearchLibrary(
        self, app: Agilent.MassHunter.Quantitative.UIModel.ILibraryApp
    ) -> None: ...
    def ShowWiderRTRange(self) -> None: ...
    def EnterManualIntegration(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def ExitManualIntegration(self) -> None: ...
    def ResetRTRange(self) -> None: ...
    def ClearManualIntegration(self) -> None: ...
    def StoreSettings(self) -> None: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def ZeroPeak(self) -> None: ...
    def GetActivePaneScale(
        self, minx: float, maxx: float, miny: float, maxy: float
    ) -> bool: ...
    def ShowIntegrationSetupDialog(self) -> None: ...
    def ShowPeakLabelsDialog(self) -> None: ...

class IChromSpecProperties(object):  # Interface
    ShowBaselines: bool
    ShowOriginalBaselines: bool

    def InitFromConfiguration(self) -> None: ...
    def GetPeakFillColor(
        self,
        isPrimary: bool,
        isManualIntegrated: bool,
        peakStatus: Agilent.MassSpectrometry.DataAnalysis.PeakStatus,
        fillPeakTransparency: int,
        fillAlternatePeaks: bool,
    ) -> System.Drawing.Color: ...

class IChromatogramInformationGridView(object):  # Interface
    def SelectAll(self) -> None: ...

class IChromatogramInformationItem(object):  # Interface
    BatchID: int  # readonly
    Color: System.Drawing.Color
    DataFileName: str  # readonly
    InstrumentName: str  # readonly
    MSScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]  # readonly
    SampleID: int  # readonly
    SampleName: str  # readonly
    Signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal  # readonly

class IChromatogramInformationUIContext(object):  # Interface
    Items: List[
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    ]  # readonly
    VisibleItemCount: int  # readonly

    def OnItemColorChanged(self, e: System.EventArgs) -> None: ...
    def IsVisible(
        self, item: Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    ) -> bool: ...
    def SetVisible(
        self,
        items: List[
            Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
        ],
        visible: bool,
    ) -> None: ...

class IChromatogramInformationView(object):  # Interface
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly

    def UpdateHighlight(self) -> None: ...
    def UpdatePeaks(self) -> None: ...

class IChromatogramInformationWindow(System.Windows.Forms.IWin32Window):  # Interface
    ChromView: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationView
    )  # readonly
    ContainsFocus: bool  # readonly
    GridView: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationGridView
    )  # readonly
    HeadToTail: bool
    Height: int
    InvokeRequired: bool  # readonly
    IsHandleCreated: bool  # readonly
    LinkXAxes: bool
    LinkYAxes: bool
    Location: System.Drawing.Point
    MaxNumVisibleRows: int
    Overlay: bool
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    UIContext: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationUIContext
    )  # readonly
    Visible: bool  # readonly
    Width: int
    WindowState: System.Windows.Forms.FormWindowState

    def AutoScaleY(self) -> None: ...
    def CanAutoScale(self) -> bool: ...
    def Copy(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def Close(self) -> None: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def AutoScaleXY(self) -> None: ...
    def Activate(self) -> None: ...
    def CanCreateCompound(self) -> bool: ...
    def CreateCompound(self) -> None: ...
    @overload
    def Invoke(self, d: System.Delegate) -> Any: ...
    @overload
    def Invoke(self, d: System.Delegate, parameters: List[Any]) -> Any: ...
    def Show(self) -> None: ...

    Disposed: System.EventHandler  # Event
    Initialized: System.EventHandler  # Event

class ICustomPane(object):  # Interface
    InitialLocation: System.Windows.Forms.AnchorStyles  # readonly
    Title: str  # readonly

    def GetControl(self) -> Any: ...

class IDataNavigator(object):  # Interface
    BatchId: int  # readonly
    CompoundGroupFilter: Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo
    CompoundId: int  # readonly
    CompoundKey: Agilent.MassHunter.Quantitative.UIModel.CompoundKey
    CompoundKeySortType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundKeySortType
    )
    CurrentCompoundRow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    )  # readonly
    CurrentIstdRow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    )  # readonly
    CurrentSampleRow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    )  # readonly
    HasIstd: bool  # readonly
    ISTDFilter: Agilent.MassHunter.Quantitative.UIModel.ISTDFilterInfo
    IsCompoundValid: bool  # readonly
    IsSampleValid: bool  # readonly
    IstdId: int  # readonly
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SampleFileInformation: (
        Agilent.MassSpectrometry.DataAnalysis.IBDAFileInformation
    )  # readonly
    SampleId: int  # readonly
    TimeSegmentFilter: Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo

    def GetTimeSegmentFilters(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo]: ...
    def GetSampleTic(self) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def GetCompoundGroupFilters(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.UIModel.CompoundGroupFilterInfo]: ...
    def GetChromatogram(
        self, pset: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def NavigateSample(self, sampleId: int) -> None: ...
    def GetISTDFilters(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.UIModel.ISTDFilterInfo]: ...
    def GetCompoundSpectrumForReferenceLibraryMatch(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...
    def GetIstdSpectrum(self) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...
    def GetFilteredCompoundKeys(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.UIModel.CompoundKey]: ...
    def GetCompoundAndQualifierSpectrum(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.ISpectrum]: ...
    @overload
    def GetCompoundChromatogram(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    @overload
    def GetCompoundChromatogram(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def GetIstdCompoundAndQualifierSpectrum(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.ISpectrum]: ...
    def GetQualifierChromatogram(
        self, compoundId: int, qualifierId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def GetTotalSignalChromatogram(
        self,
        min: float,
        max: float,
        signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal,
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    @overload
    def GetCompoundSpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...
    @overload
    def GetCompoundSpectrum(
        self,
        compoundId: int,
        mzranges: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.DoubleRange
        ],
        extractionRanges: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.DoubleRange
        ],
        startRT: float,
        endRT: float,
        pverrideSpectrum: bool,
    ) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...
    def NavigateCompound(self, sampleId: int, compoundId: int) -> None: ...
    def GetIstdChromatogram(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def GetTIC(
        self,
        msLevel: Agilent.MassSpectrometry.DataAnalysis.MSLevel,
        scanTypes: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minRT: Optional[float],
        maxRT: Optional[float],
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    def GetReferenceLibrarySpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...

    CompoundKeyChange: System.EventHandler  # Event
    NavigateChange: System.EventHandler[
        Agilent.MassHunter.Quantitative.UIModel.NavigateChangeEventArgs
    ]  # Event
    NavigateChanging: System.EventHandler[
        Agilent.MassHunter.Quantitative.UIModel.NavigateChangingEventArgs
    ]  # Event

class IDockManager(object):  # Interface
    ActivePane: Agilent.MassHunter.Quantitative.UIModel.IDockPane  # readonly

    def ControlPaneExists(self, paneId: str) -> bool: ...
    def GetPane(
        self, paneId: str
    ) -> Agilent.MassHunter.Quantitative.UIModel.IDockPane: ...

class IDockPane(object):  # Interface
    Control: System.Windows.Forms.Control  # readonly

class IEditMethodState(object):  # Interface
    CurrentCompoundId: int  # readonly
    CurrentLevelId: int  # readonly
    CurrentObjectIsCalibration: bool  # readonly
    CurrentObjectIsSample: bool  # readonly
    CurrentObjectIsTargetCompound: bool  # readonly
    CurrentObjectIsTargetQualifier: bool  # readonly
    CurrentQualifierId: int  # readonly
    IsDirty: bool  # readonly
    MethodFilePathName: str  # readonly
    OriginatedBatch: str  # readonly

    def NavigateQualifier(self, compoundId: int, qualifierId: int) -> None: ...
    def NavigateCalibration(self, compoundId: int, levelId: int) -> None: ...
    def GetTimeSegments(self) -> List[int]: ...
    def GetTargetCompoundRow(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ): ...
    def NavigateCompound(self, compoundId: int) -> None: ...
    def GetIstdCompoundRow(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ): ...

    NavigationChange: System.EventHandler  # Event

class IFlagFilter(object):  # Interface
    Category: str  # readonly
    ColumnName: str  # readonly
    Enabled: bool
    Name: str  # readonly
    OutlierCompoundType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierCompoundType
    )  # readonly
    OutlierValueColumnName: str  # readonly
    OutlierValueRelationName: str  # readonly
    RelationName: str  # readonly

    def Match(
        self,
        row: System.Data.DataRow,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierFilterType,
        backColor: System.Drawing.Color,
        foreColor: System.Drawing.Color,
    ) -> bool: ...
    def Available(
        self,
        dataset: System.Data.DataSet,
        batchFiles: Agilent.MassSpectrometry.DataAnalysis.Quantitative.BatchFiles,
        batchId: int,
    ) -> bool: ...
    def GetMessage(self, row: System.Data.DataRow) -> str: ...

class IFlagFilterManager(object):  # Interface
    Count: int  # readonly
    Filter: bool
    FilterType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierFilterType
    Flag: bool
    def __getitem__(
        self, column: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierColumns
    ) -> Agilent.MassHunter.Quantitative.UIModel.IFlagFilter: ...
    def __getitem__(
        self, index: int
    ) -> Agilent.MassHunter.Quantitative.UIModel.IFlagFilter: ...
    def BeginEdit(self) -> None: ...
    def EndEdit(self) -> None: ...

class IGridControl(object):  # Interface
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanExpandAll: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly
    ContainsFocus: bool  # readonly
    Exporting: bool
    IsInEditMode: bool  # readonly
    LastRawBandName: str  # readonly
    LastRawColumnName: str  # readonly
    UltraGrid: Infragistics.Win.UltraWinGrid.UltraGrid  # readonly

    def CanUndoInEditMode(self) -> bool: ...
    def FormatColumn(self, rawBandName: str, rawColumnName: str) -> None: ...
    def Sort(self, rawBandName: str, rawColumnName: str, ascending: bool) -> None: ...
    def DisplayPrintPreview(self) -> None: ...
    def AutoFitColumns(self) -> None: ...
    def CollapseAll(self) -> None: ...
    def IsColumnFormattable(self, rawBandName: str, rawColumnName: str) -> bool: ...
    def GetColumnCaption(self, logicalBandName: str, logicalColumnName: str) -> str: ...
    def LoadColumnSettings(self, file: str) -> None: ...
    def GetLogicalColumnName(self, rawBandName: str, rawColumnName: str) -> str: ...
    def ShowColumn(
        self, logicalBandName: str, logicalColumnName: str, columnNameAfter: str
    ) -> None: ...
    def UndoInEditMode(self) -> None: ...
    def GetLogicalBandName(self, rawBandName: str, rawColumnName: str) -> str: ...
    def Copy(self) -> None: ...
    def ExpandAll(self) -> None: ...
    def SupportsSaveLoadColumnSettings(self) -> bool: ...
    def IsColumnVisible(self, logicalBandName: str, logicalColumnName: str) -> bool: ...
    def PageSetup(self) -> None: ...
    def SaveColumnSettings(self, file: str) -> None: ...
    def Print(self, displayDialog: bool) -> None: ...
    def GetColumnNames(self, logicalBandName: str) -> List[str]: ...
    def Delete(self) -> None: ...
    def ResetColumns(self) -> None: ...
    def ResetSort(self) -> None: ...
    def HideColumn(self, logicalBandName: str, logicalColumnName: str) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def Paste(self) -> None: ...

class ILibraryApp(object):  # Interface
    HasLibrary: bool  # readonly
    TargetSpectrum: (
        Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer
    )  # readonly

    def Search(self) -> None: ...
    def SetTargetSpectrum(
        self,
        spectrum: Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer,
        massDisplayFormat: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
    ) -> None: ...
    def ShowWindow(self) -> None: ...
    def SetLibraries(
        self,
        items: List[Agilent.MassHunter.Quantitative.UIModel.ILibraryItem],
        searchType: Agilent.MassSpectrometry.DataAnalysis.MultipleLibrarySearchType,
        unitMassFormat: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
        accurateMassFormat: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
    ) -> None: ...

class ILibraryAppSite(object):  # Interface
    LibraryApp: Agilent.MassHunter.Quantitative.UIModel.ILibraryApp  # readonly

class ILibraryItem(object):  # Interface
    Library: Agilent.MassSpectrometry.DataAnalysis.ILibrary  # readonly
    Parameters: Agilent.MassSpectrometry.DataAnalysis.LibrarySearchParams  # readonly

class IMainWindow(System.Windows.Forms.IWin32Window):  # Interface
    CalCurvePane: Agilent.MassHunter.Quantitative.UIModel.ICalCurvePane  # readonly
    ChromSpecPane: Agilent.MassHunter.Quantitative.UIModel.IChromSpecPane  # readonly
    CommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AppCommandContext
    )  # readonly
    ContainsFocus: bool  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    DockManager: Agilent.MassHunter.Quantitative.UIModel.IDockManager  # readonly
    Height: int
    InvokeRequired: bool  # readonly
    IsDisposed: bool  # readonly
    IsHandleCreated: bool  # readonly
    Location: System.Drawing.Point
    MethodErrorListPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodErrorListPane
    )  # readonly
    MethodTablePane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodTablePane
    )  # readonly
    MethodTasksPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMethodTasksPane
    )  # readonly
    MetricsPlotPane: (
        Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotPane
    )  # readonly
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SampleDataPane: Agilent.MassHunter.Quantitative.UIModel.ISampleDataPane  # readonly
    ScriptPane: Agilent.MassHunter.Quantitative.UIModel.IScriptPane  # readonly
    StatusBar: Agilent.MassHunter.Quantitative.UIModel.IStatusBar  # readonly
    Text: str
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    Width: int
    WorktablePane: Agilent.MassHunter.Quantitative.UIModel.IWorktablePane  # readonly

    def RegisterCustomPane(
        self,
        register: bool,
        pane: str,
        control: Agilent.MassHunter.Quantitative.UIModel.ICustomPane,
    ) -> None: ...
    def ActivatePane(self, pane: str) -> None: ...
    def CustomPaneExists(self, key: str) -> bool: ...
    def ForceClose(self) -> None: ...
    def ResetLayout(self) -> None: ...
    def SetPaneVisible(self, pane: str, visible: bool) -> None: ...
    def ShowMethodErrorListPane(self) -> None: ...
    def IsInModalState(self) -> bool: ...
    def LayoutPanes(self, pattern: int) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def ValidateMethod(self, alwaysShowPane: bool) -> None: ...
    def Close(self) -> None: ...
    def MaximizePane(self, paneKey: str) -> None: ...
    def IsPaneVisible(self, pane: str) -> bool: ...
    def GetCustomPane(
        self, key: str
    ) -> Agilent.MassHunter.Quantitative.UIModel.ICustomPane: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def Activate(self) -> None: ...
    def ShowWindow(self) -> None: ...
    def ShowAboutBox(self) -> None: ...
    def Invoke(self, d: System.Delegate) -> Any: ...

    Closed: System.EventHandler  # Event

class IMethodErrorListPane(object):  # Interface
    def SetMessages(
        self,
        msgs: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodValidationMessage
        ],
    ) -> None: ...

class IMethodTablePane(object):  # Interface
    ArrangeCompoundsBy: str
    CalibrationsBandVisible: bool
    CanBrowseAcquisitionMethod: bool  # readonly
    CanDeleteRows: bool  # readonly
    CanFillDown: bool  # readonly
    CanGroupByTimeSegment: bool  # readonly
    CompoundsBandVisible: bool
    GridControl: Agilent.MassHunter.Quantitative.UIModel.IGridControl  # readonly
    GroupByTimeSegment: bool
    IsDisposed: bool  # readonly
    MethodEditTaskMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodEditTaskMode
    )
    OutlierSetup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierColumns
    QualifiersBandVisible: bool
    TimeSegmentFilterInfo: Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo

    def GetSelectedCompoundIds(self) -> List[int]: ...
    def GetFilteredCompoundIds(self) -> List[int]: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def DeleteRows(self) -> None: ...
    @overload
    def ActivateCell(self, columnName: str) -> None: ...
    @overload
    def ActivateCell(self, compoundId: int, columnnName: str) -> None: ...
    def GenerateStatusText(self) -> str: ...
    def FindNext(
        self,
        tableName: str,
        columnName: str,
        operatorType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType,
        value_: Any,
    ) -> bool: ...
    def BrowseAcquisitionMethod(self) -> None: ...
    def FillDown(self) -> None: ...

class IMethodTasksPane(object):  # Interface
    def GetGroup(
        self, id: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IExplorerBarGroup
    ): ...

class IMetricsPlotData(object):  # Interface
    AutoScale: bool
    NextColor: System.Drawing.Color  # readonly

    def AutoScaleY(self) -> None: ...
    def Clear(self) -> None: ...
    def AddSeries(self, column: str, color: System.Drawing.Color) -> None: ...
    def AutoScaleX(self) -> None: ...

class IMetricsPlotPane(object):  # Interface
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    PlottableGrid: Agilent.MassHunter.Quantitative.UIModel.IPlottableGrid  # readonly
    ShowAverageStdDevLines: bool

    def GetActivePaneData(
        self,
    ) -> Agilent.MassHunter.Quantitative.UIModel.IMetricsPlotData: ...

class INumberFormats(object):  # Interface
    def GetColumns(self) -> List[str]: ...
    def SetColumnNumberFormat(
        self,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        column: str,
        format: Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat,
    ) -> None: ...
    def GetColumnNumberFormat(
        self,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        name: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat: ...
    def Exists(
        self,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        name: str,
    ) -> bool: ...
    def GetColumnCategory(self, column: str) -> str: ...
    def StoreFormats(self) -> None: ...

class IPlottableColumn(object):  # Interface
    PropertyType: System.Type  # readonly
    Title: str  # readonly

    def GetValue(self, component: Any) -> Any: ...

class IPlottableGrid(object):  # Interface
    Count: int  # readonly

    def GetValue(
        self,
        index: int,
        column: Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn,
    ) -> Optional[float]: ...
    def GetSampleID(
        self,
        index: int,
        column: Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn,
    ) -> Optional[int]: ...
    def GetLabel(self, index: int) -> str: ...
    def IsPlottableColumn(
        self, column: Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn
    ) -> bool: ...
    def GetCompoundID(
        self,
        index: int,
        column: Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn,
    ) -> Optional[int]: ...
    def GetPlottableColumn(
        self, column: str
    ) -> Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn: ...

    CountChanged: System.EventHandler  # Event
    ValueChanged: System.EventHandler  # Event

class IPresentationState(object):  # Interface
    ApplicationType: str  # readonly
    BatchDirectory: str  # readonly
    BatchFileName: str  # readonly
    BatchId: int  # readonly
    CanEditMethod: bool  # readonly
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AppCommandContext
    )  # readonly
    EditMethodState: (
        Agilent.MassHunter.Quantitative.UIModel.IEditMethodState
    )  # readonly
    EditingMethod: bool  # readonly
    HasBatch: bool  # readonly
    InstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )  # readonly
    IsBatchDirty: bool  # readonly
    IsInCommandGroup: bool  # readonly
    IsWPF: bool  # readonly
    NumberFormats: Agilent.MassHunter.Quantitative.UIModel.INumberFormats  # readonly
    SubApplication: str
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly

    def BeginRunScript(
        self,
        references: List[str],
        imports: List[str],
        language: str,
        code: System.IO.TextReader,
        customStub: System.MarshalByRefObject,
        callback: System.AsyncCallback,
        asyncState: Any,
    ) -> System.IAsyncResult: ...
    def EndRunScript(self, ret: System.IAsyncResult) -> Any: ...
    def ExceptionAbort(self, ex: System.Exception) -> None: ...
    def BeginCommandGroup(self) -> None: ...
    def EndCommandGroup(self) -> None: ...
    def GetLibrary(self, pathName: str) -> T: ...
    def GetLibraryError(self, pathName: str) -> str: ...
    @overload
    def ExecuteCommand(
        self, cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand
    ) -> Any: ...
    @overload
    def ExecuteCommand(
        self,
        parent: System.Windows.Forms.IWin32Window,
        cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand,
        ret: Any,
    ) -> bool: ...
    def PerformCompliancePreCommand(
        self, parent: System.Windows.Forms.IWin32Window, commandName: str, action: str
    ) -> bool: ...
    def NotifyNumericFormatChanged(self, e: System.EventArgs) -> None: ...

    AnalysisEnd: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventHandler
    )  # Event
    AnalysisStart: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventHandler
    )  # Event
    AnalysisStep: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventHandler
    )  # Event
    ApplyMethodEnded: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ApplyMethodEventHandler
    )  # Event
    ApplyMethodStarted: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ApplyMethodEventHandler
    )  # Event
    ApplyMethodToSample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ApplyMethodEventHandler
    )  # Event
    BatchFileClosed: System.EventHandler  # Event
    BatchFileClosing: System.EventHandler  # Event
    BatchFileCreated: System.EventHandler  # Event
    BatchFileOpened: System.EventHandler  # Event
    BatchFileOpening: System.EventHandler  # Event
    BatchFileSaved: System.EventHandler  # Event
    CommandGroupEnded: System.EventHandler  # Event
    CommandGroupStarted: System.EventHandler  # Event
    CompoundIdentificationEnd: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    CompoundIdentificationStart: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    CompoundIdentificationStep: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    DeconvolutionEnd: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    DeconvolutionStart: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    DeconvolutionStep: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisEventArgs
    ]  # Event
    GraphicsSettingsChanged: System.EventHandler  # Event
    MethodEditingEnding: System.EventHandler  # Event
    MethodEditingStarted: System.EventHandler  # Event
    MethodEditingStarting: System.EventHandler  # Event
    NumericFormatChanged: System.EventHandler  # Event

class ISTDFilterInfo(
    System.IComparable[Agilent.MassHunter.Quantitative.UIModel.ISTDFilterInfo]
):  # Struct
    @overload
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType,
        istdCompoundId: int,
        compoundName: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        istd: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> None: ...

    CompoundId: int
    CompoundName: str
    Type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self, info: Agilent.MassHunter.Quantitative.UIModel.ISTDFilterInfo
    ) -> bool: ...
    @overload
    def Matches(
        self, key: Agilent.MassHunter.Quantitative.UIModel.CompoundKey
    ) -> bool: ...
    @overload
    def Matches(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> bool: ...
    def GetHashCode(self) -> int: ...
    def CompareTo(
        self, other: Agilent.MassHunter.Quantitative.UIModel.ISTDFilterInfo
    ) -> int: ...
    def ToString(self) -> str: ...

class ISampleDataPane(object):  # Interface
    AutoScale: bool
    CanAutoScale: bool  # readonly
    CanCopy: bool  # readonly
    CanCreateTargetCompound: bool  # readonly
    CanCreateTargetQualifier: bool  # readonly
    CanExtractSpectrum: bool  # readonly
    CanFindComponents: bool  # readonly
    CanNormalizeEachX: bool  # readonly
    CanSearchLibrary: bool  # readonly
    HasSpectrumPanes: bool  # readonly
    MaxNumVisibleRows: int
    NormalizeType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NormalizeType
    OverlayAllSignals: bool
    OverlayIstdCompounds: bool
    OverlayTargetCompounds: bool
    PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly
    SampleDataPath: str  # readonly
    ShowCurrentCompound: bool
    ShowTic: bool
    TimeRange: Agilent.MassSpectrometry.DataAnalysis.IRange  # readonly

    def StoreSettings(self) -> None: ...
    def GetActiveObject(self) -> T: ...
    def AutoScaleX(self) -> None: ...
    def ShowSpectrum(self, start: float, end: float) -> None: ...
    def GetMSScanColor(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Drawing.Color: ...
    def GetDisplayedMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def ShowComponents(
        self, components: Iterable[Agilent.MassSpectrometry.DataAnalysis.Component]
    ) -> None: ...
    def Copy(self) -> None: ...
    def GetAvailableSignals(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal]: ...
    def CreateTargetCompound(self) -> None: ...
    def ClearSpectrumPanes(self) -> None: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def CreateTargetQualifier(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def FindComponents(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Component
    ]: ...
    def ShowMSScan(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType, show: bool
    ) -> None: ...
    def DisplaySignal(
        self, signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal
    ) -> None: ...
    def GetAvailableMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def HideSignal(
        self, signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal
    ) -> None: ...
    def GetSignalColor(
        self, signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal
    ) -> System.Drawing.Color: ...
    def GetDisplayedSignals(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Signal]: ...
    def SearchLibrary(
        self, site: Agilent.MassHunter.Quantitative.UIModel.ILibraryApp
    ) -> None: ...

class IScriptPane(object):  # Interface
    CanCopy: bool  # readonly
    CanPaste: bool  # readonly

    def Initialize(
        self,
        engine: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptEngine,
    ) -> None: ...
    def Copy(self) -> None: ...
    def Clear(self) -> None: ...
    def Paste(self) -> None: ...
    def Run(self) -> None: ...

class ISpectrumTransfer(object):  # Interface
    AcquiredMassRangeMinimum: Optional[float]  # readonly
    CollisionEnergy: Optional[float]  # readonly
    Count: int  # readonly
    IonPolarity: Optional[Agilent.MassSpectrometry.DataAnalysis.IonPolarity]  # readonly
    IsAccurateMass: bool  # readonly
    PeakCount: int  # readonly
    RetentionTime: Optional[float]  # readonly
    ScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]  # readonly
    SelectedMz: Optional[float]  # readonly
    SignalToNoise: Optional[float]  # readonly
    Title: str  # readonly
    XValues: List[float]  # readonly
    YValues: List[float]  # readonly

    def GetPeakY(self, index: int) -> float: ...
    def GetMaxX(self) -> Optional[float]: ...
    def Normalize(self, y: float) -> None: ...
    def GetX(self, index: int) -> float: ...
    def GetY(self, index: int) -> float: ...
    def GetBasePeak(self, nx: Optional[float], ny: Optional[float]) -> None: ...
    def GetMinX(self) -> Optional[float]: ...
    def Clone(self) -> Agilent.MassHunter.Quantitative.UIModel.ISpectrumTransfer: ...
    def GetPeakX(self, index: int) -> float: ...

class IStatusBar(object):  # Interface
    Visible: bool

class IWorktablePane(object):  # Interface
    CanFillDown: bool  # readonly
    CanStartAutoReview: bool  # readonly
    CurrentLevelId: int  # readonly
    CurrentPeakId: int  # readonly
    CurrentQualifierId: int  # readonly
    DisplayAllSampleGroups: bool
    DisplayAllSampleTypes: bool
    FlagFilterManager: (
        Agilent.MassHunter.Quantitative.UIModel.IFlagFilterManager
    )  # readonly
    FontSizePercentage: float
    GridControl: Agilent.MassHunter.Quantitative.UIModel.IGridControl  # readonly
    HasNextSample: bool  # readonly
    HasPrevSample: bool  # readonly
    InvokeRequired: bool  # readonly
    LockSampleColumns: bool
    SingleCompoundMode: bool
    TableViewMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode

    def UpdateColors(self) -> None: ...
    def Invoke(self, d: System.Delegate) -> Any: ...
    def FillDown(self) -> None: ...
    def StartAutoReview(
        self, reviewCompounds: bool, manualIntegrating: bool
    ) -> None: ...
    def SetDisplaySampleType(self, type: str, display: bool) -> None: ...
    def ResetLayout(self) -> None: ...
    def HasNextCompound(self) -> bool: ...
    def ShowSelectOutliersDialog(self) -> System.Windows.Forms.DialogResult: ...
    def PrevSample(self) -> None: ...
    def GetDisplaySampleGroup(self, group: str) -> bool: ...
    def FindNext(
        self,
        tableName: str,
        columnName: str,
        operatorType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Utils.FindOperatorType,
        value_: Any,
    ) -> bool: ...
    def NextSample(self, manualIntegrating: bool) -> None: ...
    def DeleteSelectedSamples(self) -> None: ...
    def GetDisplaySampleType(self, type: str) -> bool: ...
    def GotoNextCompound(self) -> None: ...
    def GetDisplayedSampleGroups(self) -> List[str]: ...
    def CanDeleteSelectedSamples(self) -> bool: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def GenerateStatusText(self) -> str: ...
    def GetSelectedSamples(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleRowId]: ...
    def GetSamples(self) -> List[System.Data.DataRow]: ...
    def GetDisplayedSampleTypes(self) -> List[str]: ...
    def SetDisplaySampleGroup(self, group: str, display: bool) -> None: ...
    def GotoPrevCompound(self) -> None: ...
    def HasPrevCompound(self) -> bool: ...
    def RefreshSampleFilter(self) -> None: ...

class NavigateChangeEventArgs(System.EventArgs):  # Class
    def __init__(
        self,
        prevSampleId: int,
        prevCompoundId: int,
        newSampleId: int,
        newCompoundId: int,
    ) -> None: ...

    NewCompoundId: int  # readonly
    NewSampleId: int  # readonly
    PreviousCompoundId: int  # readonly
    PreviousSampleId: int  # readonly

class NavigateChangingEventArgs(System.ComponentModel.CancelEventArgs):  # Class
    def __init__(
        self,
        prevSampleId: int,
        prevCompoundId: int,
        newSampleId: int,
        newCompoundId: int,
    ) -> None: ...

    NewCompoundId: int  # readonly
    NewSampleId: int  # readonly
    PreviousCompoundId: int  # readonly
    PreviousSampleId: int  # readonly

class TimeSegmentFilterInfo(
    System.IComparable[Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo]
):  # Struct
    @overload
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType,
        timeSegment: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> None: ...

    TimeSegment: int
    Type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundFilterType

    @overload
    def Equals(
        self, info: Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo
    ) -> bool: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Matches(
        self, key: Agilent.MassHunter.Quantitative.UIModel.CompoundKey
    ) -> bool: ...
    @overload
    def Matches(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
    ) -> bool: ...
    def GetHashCode(self) -> int: ...
    def CompareTo(
        self, other: Agilent.MassHunter.Quantitative.UIModel.TimeSegmentFilterInfo
    ) -> int: ...
    def ToString(self) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Model
from .Model import (
    CommandType,
    ICommand,
    ICommandHistory,
    ICommandPrincipal,
    ILogListener,
)

# Stubs for namespace: Agilent.MassSpectrometry.CommandModel

class CodeDomLogFormatter(
    System.IDisposable, Agilent.MassSpectrometry.CommandModel.LogFormatter
):  # Class
    @overload
    def __init__(self, language: str) -> None: ...
    @overload
    def __init__(self, language: str, providerOptions: Dict[str, str]) -> None: ...
    @overload
    def __init__(self, provider: System.CodeDom.Compiler.CodeDomProvider) -> None: ...
    def Format(self, cmd: ICommand) -> str: ...

class CommandActivator(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> ICommand: ...
    def BeginInvoke(
        self, objects: List[Any], callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, objects: List[Any]) -> ICommand: ...

class CommandBase(System.IDisposable, ICommand):  # Class
    Reversible: bool  # readonly
    Type: CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def EndExecute(self, result: System.IAsyncResult) -> Any: ...
    def Execute(self) -> Any: ...
    def BeginExecute(
        self, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def Dispose(self) -> None: ...

class CommandClassAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str) -> None: ...

    Name: str  # readonly

    def GetCommandActivator(
        self, type: System.Type
    ) -> Agilent.MassSpectrometry.CommandModel.CommandActivator: ...

class CommandEntryAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

class CommandGenericPrincipal(
    Agilent.MassSpectrometry.CommandModel.CommandPrincipal, ICommandPrincipal
):  # Class
    def __init__(self) -> None: ...
    def Logon(self, user: str, roles: List[str]) -> None: ...

class CommandHistory(System.IDisposable, ICommandHistory):  # Class
    def __init__(self, capacity: int) -> None: ...

    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    Count: int  # readonly
    Principal: ICommandPrincipal
    SuppressDisposeCommands: bool

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def RevokeLogListener(self, listener: ILogListener) -> None: ...
    def Clear(self) -> None: ...
    def RegisterLogListener(self, listener: ILogListener) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> Any: ...
    def BeginInvoke(
        self, cmd: ICommand, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def Dispose(self) -> None: ...
    def Invoke(self, cmd: ICommand) -> Any: ...

    # Nested Types

    class InvokeCommand(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> Any: ...
        def BeginInvoke(
            self, cmd: ICommand, callback: System.AsyncCallback, object: Any
        ) -> System.IAsyncResult: ...
        def Invoke(self, cmd: ICommand) -> Any: ...

class CommandNoPrincipal(ICommandPrincipal):  # Class
    def __init__(self) -> None: ...

class CommandPrincipal(ICommandPrincipal):  # Class
    ...

class CommandTypeNotFoundException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class CommandWindowsPrincipal(
    Agilent.MassSpectrometry.CommandModel.CommandPrincipal, ICommandPrincipal
):  # Class
    def __init__(self) -> None: ...
    def Logon(self) -> None: ...

class CompositeCommand(
    ICommand, System.IDisposable, Agilent.MassSpectrometry.CommandModel.CommandBase
):  # Class
    Count: int  # readonly
    Reversible: bool  # readonly
    Type: CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Add(self, cmd: ICommand) -> Any: ...
    def Undo(self) -> Any: ...

class InvalidCommandDefinitionException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class InvalidCommandParameterException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(self, message: str, type: System.Type) -> None: ...

    ParameterType: System.Type  # readonly

    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class LogFormatter(System.IDisposable):  # Class
    def Dispose(self) -> None: ...
    def Format(self, cmd: ICommand) -> str: ...

class LogListener(System.IDisposable, ILogListener):  # Class
    def Dispose(self) -> None: ...
    def Log(self, cmd: ICommand) -> None: ...

class RedoCommand(
    ICommand, System.IDisposable, Agilent.MassSpectrometry.CommandModel.CommandBase
):  # Class
    def __init__(self, history: ICommandHistory) -> None: ...

    Reversible: bool  # readonly
    Type: CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class RuntimeCommand(
    ICommand, System.IDisposable, Agilent.MassSpectrometry.CommandModel.CommandBase
):  # Class
    @overload
    def __init__(
        self,
        history: ICommandHistory,
        getTargetMethodName: str,
        getTargetParameters: List[Any],
        methodName: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        history: ICommandHistory,
        getTargetMethodName: str,
        getTargetParameters: List[Any],
        methodName: str,
        parameters: List[Any],
    ) -> None: ...
    @overload
    def __init__(
        self,
        history: ICommandHistory,
        getTargetMethodName: str,
        getTargetParameters: List[Any],
        methodName: str,
        parameters: List[Any],
        undoMethodName: str,
        undoParameters: List[Any],
    ) -> None: ...

    Reversible: bool  # readonly
    Type: CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class ScriptCompile:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GenerateCodeScriptClass(
        nameSpace: System.CodeDom.CodeNamespace,
        className: str,
        baseClassName: str,
        mainMethodName: str,
        scriptCode: System.IO.TextReader,
    ) -> None: ...
    @staticmethod
    def GenerateCodeCommandMethod(
        typeClass: System.CodeDom.CodeTypeDeclaration,
        commandType: System.Type,
        commandName: str,
        constructor: System.Reflection.ConstructorInfo,
    ) -> None: ...
    @staticmethod
    def GenerateCodeCustomStubMethod(
        typeClass: System.CodeDom.CodeTypeDeclaration,
        stubType: System.Type,
        methodInfo: System.Reflection.MethodInfo,
    ) -> None: ...
    @staticmethod
    def GenerateCodeCustomStubProperties(
        typeClass: System.CodeDom.CodeTypeDeclaration,
        stubType: System.Type,
        propertyInfo: System.Reflection.PropertyInfo,
    ) -> None: ...
    @staticmethod
    def GenerateCodeCommandEntries(
        typeClass: System.CodeDom.CodeTypeDeclaration, commandAssemblies: List[str]
    ) -> None: ...
    @staticmethod
    def GenerateCodeScriptBaseClass(
        codeNamespace: System.CodeDom.CodeNamespace,
        className: str,
        mainMethodName: str,
        customStub: Any,
        commandAssemblies: List[str],
    ) -> None: ...
    @staticmethod
    def CreateCompileUnitBaseClass(
        namespaceName: str,
        className: str,
        mainMethodName: str,
        customStub: Any,
        commandAssemblies: List[str],
        imports: List[str],
    ) -> System.CodeDom.CodeCompileUnit: ...
    @staticmethod
    def CreateCompileUnitScriptClass(
        namespaceName: str,
        className: str,
        baseClassName: str,
        mainMethodName: str,
        imports: List[str],
        scriptCode: System.IO.TextReader,
    ) -> System.CodeDom.CodeCompileUnit: ...
    @staticmethod
    def GenerateCodeCustomStubMembers(
        typeClass: System.CodeDom.CodeTypeDeclaration, customStub: Any
    ) -> None: ...

class ScriptCompilerErrors:  # Class
    Count: int  # readonly
    def __getitem__(self, index: int) -> System.CodeDom.Compiler.CompilerError: ...
    def GetErrorNumber(self, index: int) -> str: ...
    def GetErrorText(self, index: int) -> str: ...

class ScriptHost:  # Class
    @staticmethod
    def BeginRun(
        parameters: Agilent.MassSpectrometry.CommandModel.ScriptParameters,
        callback: System.AsyncCallback,
        asyncState: Any,
    ) -> System.IAsyncResult: ...
    @staticmethod
    def EndRun(result: System.IAsyncResult) -> Any: ...
    @staticmethod
    def Run(
        parameters: Agilent.MassSpectrometry.CommandModel.ScriptParameters,
    ) -> Any: ...

    # Nested Types

    class AsyncResult(
        Agilent.MassSpectrometry.CommandModel.ScriptMarshalByRefObject,
        System.IDisposable,
        System.IAsyncResult,
    ):  # Class
        def OnScriptEnd(self) -> None: ...

    class RemoteHost(System.MarshalByRefObject, System.IDisposable):  # Class
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, language: str, providerOptions: Dict[str, str]) -> None: ...

        CompilerErrorCount: int  # readonly
        TempFiles: List[str]  # readonly

        def BeginRun(
            self, parameters: Agilent.MassSpectrometry.CommandModel.ScriptParameters
        ) -> None: ...
        def GetCompilerError(
            self,
            index: int,
            fileName: str,
            line: int,
            column: int,
            errorNumber: str,
            errorText: str,
        ) -> None: ...
        def Dispose(self) -> None: ...
        def EndRun(self) -> Any: ...
        def Run(
            self, parameters: Agilent.MassSpectrometry.CommandModel.ScriptParameters
        ) -> Any: ...

class ScriptMarshalByRefObject(System.MarshalByRefObject, System.IDisposable):  # Class
    def Dispose(self) -> None: ...
    def InitializeLifetimeService(self) -> Any: ...

class ScriptParameters(
    System.IDisposable, Agilent.MassSpectrometry.CommandModel.ScriptMarshalByRefObject
):  # Class
    def __init__(
        self,
        customStub: System.MarshalByRefObject,
        commandContext: Any,
        commandAssemblies: List[str],
        debug: bool,
        language: str,
        scriptCode: System.IO.TextReader,
    ) -> None: ...

    CommandAssemblies: List[str]  # readonly
    CommandContext: Any  # readonly
    CommandProxyAssemblyName: str
    CustomStub: System.MarshalByRefObject  # readonly
    Debug: bool  # readonly
    Imports: List[str]
    Language: str  # readonly
    OutputFolder: str
    ReferenceAssemblies: List[str]
    ScriptCode: System.IO.TextReader
    SkipGenerateCommandProxyClass: bool

    def AddProviderOption(self, key: str, value_: str) -> None: ...

class ScriptProxy:  # Class
    ReturnValue: Any

class ScriptStub(
    System.IDisposable, Agilent.MassSpectrometry.CommandModel.ScriptMarshalByRefObject
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, context: Any, customStub: System.MarshalByRefObject) -> None: ...

    CustomStub: System.MarshalByRefObject  # readonly

    def ExecuteCommand(self, typeName: str, parameters: List[Any]) -> Any: ...
    def ExecuteCommandWithParameterArray(
        self, typeName: str, dummy: int, parameters: List[Any]
    ) -> Any: ...
    def Dispose(self) -> None: ...

class TextWriterLogListener(
    System.IDisposable, ILogListener, Agilent.MassSpectrometry.CommandModel.LogListener
):  # Class
    def __init__(
        self,
        writer: System.IO.TextWriter,
        formatter: Agilent.MassSpectrometry.CommandModel.LogFormatter,
    ) -> None: ...

class UndoCommand(
    ICommand, System.IDisposable, Agilent.MassSpectrometry.CommandModel.CommandBase
):  # Class
    def __init__(self, history: ICommandHistory) -> None: ...

    Reversible: bool  # readonly
    Type: CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IBlankHits, UnknownsAnalysisDataSet
from .Command import CommandContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Utils

class BlankHits(System.IDisposable, IBlankHits):  # Class
    def __init__(self, context: CommandContext) -> None: ...

    BlankSampleCount: int  # readonly

    def HasBlankHits(
        self,
        hit: UnknownsAnalysisDataSet.HitRow,
        parentComponent: UnknownsAnalysisDataSet.ComponentRow,
        modelIonPeak: UnknownsAnalysisDataSet.IonPeakRow,
        method: UnknownsAnalysisDataSet.BlankSubtractionMethodRow,
    ) -> bool: ...
    def Dispose(self) -> None: ...

class LibraryMzValues(System.IDisposable):  # Class
    def __init__(self, context: CommandContext) -> None: ...
    def Dispose(self) -> None: ...
    def GetLibraryMzValues(
        self, lsmrows: List[UnknownsAnalysisDataSet.LibrarySearchMethodRow]
    ) -> System.Collections.Generic.List[float]: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .Engine import IReportContext
from .Template import (
    IDataBinding,
    IDataFilter,
    IDefaultFont,
    IFieldValue,
    IFont,
    IImage,
    ILength,
    IReportTemplate,
    ITextbox,
    TextboxContentType,
)

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Extensions

class ConvertUnits:  # Class
    @overload
    @staticmethod
    def ConvertTo(length: ILength, graphics: System.Drawing.Graphics) -> float: ...
    @overload
    @staticmethod
    def ConvertTo(value_: float, graphics: System.Drawing.Graphics) -> ILength: ...

class FontUtils:  # Class
    def __init__(self) -> None: ...

    DefaultFontName: str = ...  # static # readonly

    @staticmethod
    def GetFont(font: IFont, defaultFont: IFont) -> IFont: ...
    @staticmethod
    def GetDefaultFont(
        fonts: List[IDefaultFont], ci: System.Globalization.CultureInfo
    ) -> IFont: ...

class ReportExtension:  # Class
    @staticmethod
    def GetValue(field: IFieldValue, context: IReportContext) -> Any: ...
    @staticmethod
    def ToSignificantDigits(
        value_: float, significant_digits: int, provider: System.IFormatProvider
    ) -> str: ...
    @staticmethod
    def GetFilterString(
        dataBinding: IDataBinding,
        context: IReportContext,
        table: System.Data.DataTable,
        top: IDataFilter,
        belongToGroup: IDataFilter,
    ) -> str: ...
    @staticmethod
    def Process(template: IReportTemplate, context: IReportContext) -> None: ...
    @staticmethod
    def GetFilePath(image: IImage, templateFilePath: str) -> str: ...
    @staticmethod
    def ConvertTo(value_: Any, defaultValue: T) -> T: ...
    @staticmethod
    def GetContentType(textbox: ITextbox) -> TextboxContentType: ...
    @staticmethod
    def ProcessMacro(context: IReportContext, text: str) -> str: ...
    @staticmethod
    def GetText(textbox: ITextbox, context: IReportContext) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import ComponentFilter, ComponentHitID
from .Common import LibrarySearchSite
from .ScriptIF import ChromatogramViewMode, IUIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model

class IAnalysisMessageGridView(object):  # Interface
    ContextMenuStrip: System.Windows.Forms.ContextMenuStrip
    DataGridView: System.Windows.Forms.DataGridView  # readonly

    def Initialize(
        self,
        window: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...

class IAnalysisMessageTableControl(object):  # Interface
    AnalysisMessageGridView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IAnalysisMessageGridView
    )  # readonly

class IChromatogramControl(object):  # Interface
    ChromatogramView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IChromatogramView
    )  # readonly

class IChromatogramView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IPlotControlBase
):  # Interface
    ChromatogramViewMode: ChromatogramViewMode
    ShowComponents: bool
    ShowEics: bool
    ShowTic: bool

    def Initialize(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...
    def AutoScaleY(self) -> None: ...
    def UpdateSettings(self) -> None: ...
    def UpdatePeakLabels(self) -> None: ...
    def UpdateSeriesVisibility(self) -> None: ...
    def UpdatePeakLabelSettings(self) -> None: ...

class IComponentGridView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IGridControlBase
):  # Interface
    CanDeleteComponentsHits: bool  # readonly
    CanSetBestHits: bool  # readonly
    SelectedComponentBackColor: System.Drawing.Color
    SelectedComponentForeColor: System.Drawing.Color

    def Initialize(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...
    def ExportTableToLibrary(
        self,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def SetBestHits(self) -> None: ...
    def GetVisibleColumns(self) -> List[str]: ...
    def DeleteComponentsHits(self) -> None: ...
    def RestoreComponentsHits(self) -> None: ...
    def ExportToQuantMethod(
        self,
        destination: str,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
        ionMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodFromLibraryIonMode,
        numQualifiers: int,
    ) -> None: ...
    def SelectNearestComponent(self, rt: float) -> None: ...

class IComponentTableControl(object):  # Interface
    ComponentGridView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IComponentGridView
    )  # readonly

class IComponentTableView(object):  # Interface
    BestHitsOnly: bool
    BestPrimaryHitsOnly: bool
    BlankSubtractedHits: bool
    Count: int  # readonly
    Filter: ComponentFilter
    def __getitem__(self, index: int) -> ComponentHitID: ...
    PrimaryHitsOnly: bool

    def GetWhereClause(self) -> str: ...
    def GetCount(
        self,
        batchId: int,
        sampleId: int,
        filter: ComponentFilter,
        hideBlankSubtracted: bool,
        bestHitsOnly: bool,
        primaryHitsOnly: bool,
    ) -> int: ...

    TableChanged: System.EventHandler  # Event

class IEicPeaksControl(object):  # Interface
    EicPeaksView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IEicPeaksView
    )  # readonly

class IEicPeaksView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IPlotControlBase
):  # Interface
    def Initialize(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
        mainWindow: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
    ) -> None: ...
    def UpdateSettings(self) -> None: ...

class IExactMassGridView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IGridControlBase
):  # Interface
    def CanShowAlternativeExactMassDialog(self) -> bool: ...
    def Initialize(
        self,
        mainWindow: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
    ) -> None: ...
    def ShowAlternativeExactMassDialog(self) -> None: ...

class IExactMassTableControl(object):  # Interface
    ExactMassGridView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IExactMassGridView
    )  # readonly

class IGridControlBase(object):  # Interface
    CanCopy: bool  # readonly
    CanSetColumnFormat: bool  # readonly
    ContextMenuStrip: System.Windows.Forms.ContextMenuStrip
    DataGridView: System.Windows.Forms.DataGridView  # readonly
    Handle: System.IntPtr  # readonly
    IsCurrentCellInEditMode: bool  # readonly
    RowCount: int  # readonly

    def Copy(self) -> None: ...
    def ExportToCsv(
        self,
        allComponents: bool,
        writer: System.IO.TextWriter,
        delimiter: str,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def SetColumnFormat(self) -> None: ...

class IIonPeakTableView(object):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IIonPeakViewItem
    ): ...
    def FindItem(self, x: float) -> int: ...
    def ShowDefaultIons(self) -> None: ...
    def ToggleVisible(self, index: int) -> bool: ...
    def AddIon(self, x: float) -> None: ...
    def Clear(self) -> None: ...
    def UpdateColors(self) -> None: ...

    VisibleIonPeaksChanged: System.EventHandler  # Event

class IIonPeakViewItem(object):  # Interface
    Abundance: float  # readonly
    BatchID: int  # readonly
    Color: System.Drawing.Color
    ComponentID: int  # readonly
    DeconvolutionMethodID: int  # readonly
    IonPeakID: int  # readonly
    MZ: float  # readonly
    SampleID: int  # readonly
    Visible: bool  # readonly

class IIonPeaksControl(object):  # Interface
    IonPeaksView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IIonPeaksView
    )  # readonly

class IIonPeaksView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IPlotControlBase
):  # Interface
    ShowComponent: bool
    ShowTIC: bool
    UIContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext
    )  # readonly

    def Initialize(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...
    def UpdateSettings(self) -> None: ...

class IMainWindow(System.Windows.Forms.IWin32Window):  # Interface
    ActivePane: str  # readonly
    AddInManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInManager
    )  # readonly
    AnalysisMessageTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IAnalysisMessageTableControl
    )  # readonly
    ChromatogramControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IChromatogramControl
    )  # readonly
    ComponentTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IComponentTableControl
    )  # readonly
    EicPeaksControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IEicPeaksControl
    )  # readonly
    ExactMassTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IExactMassTableControl
    )  # readonly
    InvokeRequired: bool  # readonly
    IonPeaksControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IIonPeaksControl
    )  # readonly
    IsDisposed: bool  # readonly
    IsHandleCreated: bool  # readonly
    SampleTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISampleTableControl
    )  # readonly
    ScriptControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptControl
    )  # readonly
    SpectrumControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISpectrumControl
    )  # readonly
    StructureControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IStructureControl
    )  # readonly
    Title: str
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    UIContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext
    )  # readonly
    UIState: IUIState  # readonly

    def ActivateWindow(self) -> None: ...
    def SetLayout(self, layout: int) -> None: ...
    def SetPaneVisible(self, key: str, visible: bool) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    @overload
    def Close(self) -> None: ...
    @overload
    def Close(self, forceClose: bool) -> None: ...
    def IsPaneVisible(self, key: str) -> bool: ...
    def BeginInvoke(self, d: System.Delegate, parameters: List[Any]) -> None: ...
    def SaveLayout(self, straem: System.IO.Stream) -> None: ...
    def ShowQuery(self, queryFile: str) -> None: ...
    def Invoke(self, d: System.Delegate, parameters: List[Any]) -> Any: ...

    Closed: System.EventHandler  # Event
    PaneVisibleChanged: System.EventHandler  # Event

class IPlotControlBase(object):  # Interface
    CanAutoScaleXY: bool  # readonly
    _PlotControl: Agilent.MassSpectrometry.GUI.Plot.PlotControl  # readonly

    def PrintDialog(
        self,
        pageSettings: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings,
    ) -> None: ...
    def SetContextMenuInternal(
        self, contextMenu: System.Windows.Forms.ContextMenuStrip
    ) -> None: ...
    def AutoScaleXY(self) -> None: ...
    def PrintPreview(
        self,
        pageSettings: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.PlotPageSettings,
    ) -> None: ...
    def Invalidate(self) -> None: ...

class ISampleGridView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IGridControlBase
):  # Interface
    def Initialize(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...
    def StoreVisibleColumns(self) -> None: ...

class ISampleTableControl(object):  # Interface
    SampleGridView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISampleGridView
    )  # readonly

class ISelectedRanges(object):  # Interface
    Count: int  # readonly
    HasTempSelection: bool  # readonly

    def GetTempSelection(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID,
        range: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
    ) -> None: ...
    def SetTempSelection(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID,
        range: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
    ) -> None: ...
    def HitTest(
        self, batchID: int, sampleID: int, rt: float
    ) -> Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange]: ...
    def RemoveRange(
        self,
        batchID: int,
        sampleID: int,
        range: Agilent.MassSpectrometry.GUI.Plot.PlotRange,
        suppressEvent: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def GetRanges(
        self, batchID: int, sampleID: int
    ) -> Iterable[Agilent.MassSpectrometry.GUI.Plot.PlotRange]: ...
    def AddRange(
        self,
        batchID: int,
        sampleID: int,
        range: Agilent.MassSpectrometry.GUI.Plot.PlotRange,
    ) -> None: ...
    def GetSamples(
        self,
    ) -> Iterable[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]: ...

    SelectionChanged: System.EventHandler  # Event
    TempSelectionChanged: System.EventHandler  # Event

class ISpectrumControl(object):  # Interface
    SpectrumView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISpectrumView
    )  # readonly

class ISpectrumView(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IPlotControlBase
):  # Interface
    CanAutoScaleXY: bool  # readonly
    CanCopy: bool  # readonly
    HeadToTailView: bool
    ShowExtractedSpectrum: bool

    def GetActiveObject(self) -> T: ...
    def Initialize(
        self,
        uiContext: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext,
    ) -> None: ...
    def Copy(self) -> None: ...
    def UpdateSettings(self) -> None: ...
    def SetContextMenuInternal(
        self, contextMenu: System.Windows.Forms.ContextMenuStrip
    ) -> None: ...
    def AutoScaleXY(self) -> None: ...
    def Invalidate(self) -> None: ...

class IStructureControl(object):  # Interface
    CanCopy: bool  # readonly
    ClientRectangle: System.Drawing.Rectangle  # readonly
    Control: System.Windows.Forms.Control  # readonly
    Handle: System.IntPtr  # readonly

    def Copy(self) -> None: ...
    def DrawTo(
        self,
        g: System.Drawing.Graphics,
        color: System.Drawing.Color,
        rect: System.Drawing.Rectangle,
    ) -> None: ...

class IUIContext(object):  # Interface
    AccurateMassExtension: bool
    BlankComponent: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ComponentRowID
    )
    CommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext
    )  # readonly
    ComponentTableView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IComponentTableView
    )  # readonly
    DataFile: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataFile.DataFileBase
    )  # readonly
    IonPeakTableView: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IIonPeakTableView
    )  # readonly
    IsWPF: bool  # readonly
    LibrarySearchSite: LibrarySearchSite  # readonly
    SelectedComponentHitCount: int  # readonly
    SelectedExactMassCount: int  # readonly
    SelectedRanges: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISelectedRanges
    )  # readonly
    SelectedSampleCount: int  # readonly
    SelectedSamples: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]  # readonly
    SelectingSamples: bool  # readonly
    SingleSelectedSampleRowID: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    )  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    WalkingChromatogramRanges: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISelectedRanges
    )  # readonly

    def IsComponentSelected(
        self, batchID: int, sampleID: int, deconvolutionMethodID: int, componentID: int
    ) -> bool: ...
    def IdleInvoke(self, d: System.Delegate, parameters: List[Any]) -> None: ...
    def GetSelectedExactMass(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ExactMassRowID: ...
    def SelectSamples(
        self,
        srids: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
        ],
    ) -> None: ...
    def SelectComponentHits(
        self, chids: Iterable[ComponentHitID], clearSelection: bool
    ) -> None: ...
    def IsSelected(self, batchId: int, sampleId: int) -> bool: ...
    def GetSelectedComponentHitID(self, index: int) -> ComponentHitID: ...
    def SelectExactMasses(
        self,
        emrids: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ExactMassRowID
        ],
        clearSelection: bool,
    ) -> None: ...

    AnalysisClosed: System.EventHandler  # Event
    AnalysisClosing: System.EventHandler  # Event
    AnalysisNew: System.EventHandler  # Event
    AnalysisOpened: System.EventHandler  # Event
    AnalysisOpening: System.EventHandler  # Event
    AnalysisSaved: System.EventHandler  # Event
    AnalysisSaving: System.EventHandler  # Event
    BlankComponentChanged: System.EventHandler  # Event
    ComponentHitSelectionChanged: System.EventHandler  # Event
    CurrentSampleChanged: System.EventHandler  # Event
    ExactMassSelectionChanged: System.EventHandler  # Event
    SampleSelectionChanged: System.EventHandler  # Event

class PaneIds:  # Class
    AnalysisMessage: str = ...  # static # readonly
    Chromatogram: str = ...  # static # readonly
    ComponentTable: str = ...  # static # readonly
    EicPeaks: str = ...  # static # readonly
    ExactMass: str = ...  # static # readonly
    HitTable: str = ...  # static # readonly
    IonPeaks: str = ...  # static # readonly
    SampleTable: str = ...  # static # readonly
    Script: str = ...  # static # readonly
    Spectrum: str = ...  # static # readonly
    Structure: str = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NLR

class Funcs(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> float: ...
    def BeginInvoke(
        self,
        x: float,
        a: List[float],
        dyda: List[float],
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, x: float, a: List[float], dyda: List[float]) -> float: ...

class INewtonRaphsonFunc(object):  # Interface
    def Value(self, x: float) -> float: ...
    def ValueDF(self, x: float, dfdx: float) -> float: ...

class LevenbergMarquardt:  # Class
    def __init__(
        self,
        xx: List[float],
        yy: List[float],
        ssig2: List[float],
        aa: List[float],
        funks: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NLR.Funcs,
        TOL: float,
    ) -> None: ...

    ChiSquare: float  # readonly
    Covariance: List[List[float]]  # readonly
    FitParams: List[float]  # readonly

    def Fit(self) -> None: ...

class LevenbergMarquartdConvergenceException(
    System.ApplicationException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...

class NewtonRaphson:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def FindRoot(
        func: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NLR.INewtonRaphsonFunc,
        xLow: float,
        xHigh: float,
        xTolerance: float,
    ) -> float: ...
    @staticmethod
    def SafeFindRoot(
        func: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NLR.INewtonRaphsonFunc,
        xLow: float,
        xHigh: float,
        xTolerance: float,
    ) -> float: ...

class NewtonRaphsonConvergenceException(
    System.ApplicationException,
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, msg: str) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Template import (
    BreakLocation,
    DataFilterOperator,
    HorizontalAlign,
    LengthUnit,
    LineStyle,
    PageOrientation,
    TextboxContentType,
    VerticalAlign,
)

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataModel

class IBorders(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.DataModel.ILine  # readonly
    Left: Agilent.MassHunter.ReportBuilder.DataModel.ILine  # readonly
    Right: Agilent.MassHunter.ReportBuilder.DataModel.ILine  # readonly
    Top: Agilent.MassHunter.ReportBuilder.DataModel.ILine  # readonly

class IDataBinding(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    BindingName: str  # readonly
    ChildDataBinding: (
        Agilent.MassHunter.ReportBuilder.DataModel.IDataBinding
    )  # readonly
    DataName: str  # readonly
    Expression: str  # readonly
    Filters: List[Agilent.MassHunter.ReportBuilder.DataModel.IDataFilter]  # readonly
    Orders: List[Agilent.MassHunter.ReportBuilder.DataModel.IDataOrder]  # readonly

class IDataBindingContainer(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    DataBinding: Agilent.MassHunter.ReportBuilder.DataModel.IDataBinding  # readonly

class IDataFilter(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    FieldName: str  # readonly
    FieldValue: Agilent.MassHunter.ReportBuilder.DataModel.IFieldValue  # readonly
    Operator: DataFilterOperator  # readonly
    Value: str  # readonly

class IDataOrder(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Ascending: bool  # readonly
    FieldName: str  # readonly

class IFieldValue(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    BindingName: str  # readonly
    FieldName: str  # readonly
    Parent: Agilent.MassHunter.ReportBuilder.DataModel.ISelectable  # readonly

class IFont(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Bold: Optional[bool]  # readonly
    Italic: Optional[bool]  # readonly
    Name: str  # readonly
    Size: Optional[float]  # readonly
    Strikeout: Optional[bool]  # readonly
    Underline: Optional[bool]  # readonly

class IGraphics(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    Height: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Name: str  # readonly
    Parameters: List[
        Agilent.MassHunter.ReportBuilder.DataModel.IGraphicsParameter
    ]  # readonly
    Width: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    WidthPercentage: float  # readonly

class IGraphicsParameter(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    FieldValue: Agilent.MassHunter.ReportBuilder.DataModel.IFieldValue  # readonly
    Name: str  # readonly
    Value: str  # readonly

class IHeaderFooter(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
):  # Interface
    BackgroundColor: System.Drawing.Color
    Borders: Agilent.MassHunter.ReportBuilder.DataModel.IBorders  # readonly
    Center: Agilent.MassHunter.ReportBuilder.DataModel.IHeaderFooterContent  # readonly
    Height: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.DataModel.IHeaderFooterContent  # readonly
    Page: Agilent.MassHunter.ReportBuilder.DataModel.IPage  # readonly
    Right: Agilent.MassHunter.ReportBuilder.DataModel.IHeaderFooterContent  # readonly

class IHeaderFooterContent(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    ...

class IImage(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    File: str  # readonly
    Height: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly

class ILength(object):  # Interface
    Unit: LengthUnit  # readonly
    Value: float  # readonly

    def ValueAs(self, unit: LengthUnit) -> float: ...
    def ToString(self, culture: System.Globalization.CultureInfo) -> str: ...

class ILine(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Color: System.Drawing.Color  # readonly
    LineStyle: LineStyle  # readonly
    Width: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly

class IList(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.IDataBindingContainer,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
):  # Interface
    Hidden: bool  # readonly
    PageBreak: BreakLocation  # readonly

class ILocalizableFieldValue(
    Agilent.MassHunter.ReportBuilder.DataModel.IFieldValue,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    Localize: bool  # readonly

class ILocalizedText(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    Key: str  # readonly

class IMargins(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly

class IPaddings(Agilent.MassHunter.ReportBuilder.DataModel.IReportObject):  # Interface
    Bottom: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Left: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Right: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    Top: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly

class IPage(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
):  # Interface
    Footer: Agilent.MassHunter.ReportBuilder.DataModel.IHeaderFooter  # readonly
    Header: Agilent.MassHunter.ReportBuilder.DataModel.IHeaderFooter  # readonly
    Margins: Agilent.MassHunter.ReportBuilder.DataModel.IMargins  # readonly
    PageOrientation: PageOrientation  # readonly

class IReport(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
):  # Interface
    Copyright: str  # readonly
    DesignerType: str  # readonly
    EditorVersion: str  # readonly
    IsDirty: bool  # readonly
    Pages: List[Agilent.MassHunter.ReportBuilder.DataModel.IPage]  # readonly
    SchemaVersion: int  # readonly
    TemplateFilePath: str  # readonly
    TextSets: Agilent.MassHunter.ReportBuilder.DataModel.ITextSets  # readonly

    def FindNewID(self, basename: str) -> str: ...

class IReportObject(object):  # Interface
    Report: Agilent.MassHunter.ReportBuilder.DataModel.IReport  # readonly

class IScriptBox(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    Script: str

class ISelectable(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    Container: (
        Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer
    )  # readonly
    DisplayTypeName: str  # readonly
    ID: str  # readonly

class ISelectableContainer(
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject
):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassHunter.ReportBuilder.DataModel.ISelectable: ...
    def CanInsertScriptBox(self) -> bool: ...
    def CanInsertImage(self) -> bool: ...
    def IndexOf(
        self, selectable: Agilent.MassHunter.ReportBuilder.DataModel.ISelectable
    ) -> int: ...
    def CanInsertGraphics(self) -> bool: ...
    def CanInsertTable(self) -> bool: ...
    def CanInsertList(self) -> bool: ...
    def CanInsertTextbox(self) -> bool: ...
    def FindByID(
        self, id: str
    ) -> Agilent.MassHunter.ReportBuilder.DataModel.ISelectable: ...

class ITable(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.IDataBindingContainer,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
):  # Interface
    ColumnCount: int  # readonly
    Columns: str  # readonly
    DefaultCellBorders: Agilent.MassHunter.ReportBuilder.DataModel.IBorders  # readonly
    Flow: bool  # readonly
    HeaderRows: int  # readonly
    Hidden: bool  # readonly
    HorizontalAlign: HorizontalAlign  # readonly
    KeepTogether: bool  # readonly
    PageBreak: BreakLocation  # readonly
    RelativeColumnWidths: str  # readonly
    SpacingBefore: Agilent.MassHunter.ReportBuilder.DataModel.ILength  # readonly
    WidthPercentage: float  # readonly

class ITableCell(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
):  # Interface
    Borders: Agilent.MassHunter.ReportBuilder.DataModel.IBorders  # readonly
    ColumnSpan: int  # readonly
    Content: Agilent.MassHunter.ReportBuilder.DataModel.ISelectable  # readonly
    Row: Agilent.MassHunter.ReportBuilder.DataModel.ITableRow  # readonly

class ITableCellContent(object):  # Interface
    Borders: Agilent.MassHunter.ReportBuilder.DataModel.IBorders  # readonly
    ColumnSpan: int  # readonly

class ITableRow(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
):  # Interface
    Table: Agilent.MassHunter.ReportBuilder.DataModel.ITable  # readonly

class ITextSets(object):  # Interface
    def GetValue(self, name: str, culture: str, value_: str) -> bool: ...
    def SetValue(self, name: str, culture: str, value_: str) -> None: ...
    def Remove(self, name: str, culture: str) -> None: ...
    def Exists(self, name: str, culture: str) -> bool: ...
    def GetNames(self) -> List[str]: ...

class ITextbox(
    Agilent.MassHunter.ReportBuilder.DataModel.ISelectable,
    Agilent.MassHunter.ReportBuilder.DataModel.IReportObject,
):  # Interface
    BackgroundColor: System.Drawing.Color  # readonly
    Color: System.Drawing.Color  # readonly
    ContentType: TextboxContentType  # readonly
    Expression: str  # readonly
    FieldCaption: Agilent.MassHunter.ReportBuilder.DataModel.IFieldValue  # readonly
    FieldFormat: Agilent.MassHunter.ReportBuilder.DataModel.IFieldValue  # readonly
    FieldValue: (
        Agilent.MassHunter.ReportBuilder.DataModel.ILocalizableFieldValue
    )  # readonly
    Font: Agilent.MassHunter.ReportBuilder.DataModel.IFont  # readonly
    Format: str  # readonly
    HorizontalAlign: HorizontalAlign  # readonly
    LocalizedText: Agilent.MassHunter.ReportBuilder.DataModel.ILocalizedText  # readonly
    OutlineLevel: Optional[int]  # readonly
    Paddings: Agilent.MassHunter.ReportBuilder.DataModel.IPaddings  # readonly
    Text: str  # readonly
    VerticalAlign: VerticalAlign  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import ChromatogramPeakLabelType, DataNavigator, NormalizeType, Signal
from .Controls2 import IPropertyPage
from .Toolbar import IToolbarsManager

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData

class DataUtils:  # Class
    @staticmethod
    def GetTic(
        dataNavigator: DataNavigator,
        scanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType],
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...
    @staticmethod
    def GetSignalChromatogram(
        dataNavigator: DataNavigator, signal: Signal
    ) -> Agilent.MassSpectrometry.DataAnalysis.IChromatogram: ...

class PlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    AutoScale: bool
    CanAutoScale: bool  # readonly
    CanCopy: bool  # readonly
    CanCreateTargetCompound: bool  # readonly
    CanCreateTargetQualifier: bool  # readonly
    CanFindComponents: bool  # readonly
    CanNormalizeEachX: bool  # readonly
    CanSearchLibrary: bool  # readonly
    DataNavigator: DataNavigator
    DisplayAllSignals: bool
    HasSpectrumPanes: bool  # readonly
    HasTic: bool  # readonly
    MaxNumVisibleRows: int
    NormalizeType: NormalizeType
    OverlayAllSignals: bool
    OverlayIstdCompounds: bool
    OverlayTargetCompounds: bool
    Properties: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData.SampleInfoProperties
    )  # readonly
    SampleDataPath: str  # readonly
    ShowCurrentCompound: bool
    ShowTic: bool
    TicColor: System.Drawing.Color
    TimeRange: Agilent.MassSpectrometry.DataAnalysis.IRange  # readonly
    ToolbarsManager: IToolbarsManager

    def GetActiveObject(self) -> T: ...
    def GetPreferredYRangeLimit(
        self, row: int, column: int
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def AutoScaleX(self) -> None: ...
    def EnsureTimeRangeContainsScanLine(
        self, range: Agilent.MassSpectrometry.DataAnalysis.IRange
    ) -> Agilent.MassSpectrometry.DataAnalysis.IRange: ...
    def ShowSpectrum(self, x1: float, x2: float) -> None: ...
    def GetAutoScaleRangeX(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetMSScanColor(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Drawing.Color: ...
    @overload
    def DrawTicTo(
        self,
        graphics: System.Drawing.Graphics,
        bounds: System.Drawing.Rectangle,
        xrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
        yrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
    ) -> None: ...
    @overload
    def DrawTicTo(
        self,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
        bounds: System.Drawing.Rectangle,
        xrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
        yrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
    ) -> None: ...
    @overload
    def DrawTicTo(
        self,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
        scanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType],
        bounds: System.Drawing.Rectangle,
        xrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
        yrange: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange],
        paintBackground: bool,
    ) -> None: ...
    def GetDisplayedMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def ShowComponents(
        self, components: Iterable[Agilent.MassSpectrometry.DataAnalysis.Component]
    ) -> None: ...
    def Copy(self) -> None: ...
    def GetAvailableSignals(self) -> List[Signal]: ...
    @staticmethod
    def CompareSignal(signal1: Signal, signal2: Signal) -> int: ...
    def CreateTargetCompound(self) -> None: ...
    def ClearSpectrumPanes(self) -> None: ...
    def CreatePropertyPages(self) -> List[IPropertyPage]: ...
    def InitConfiguration(self) -> None: ...
    def CreateTargetQualifier(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def FindComponents(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Component
    ]: ...
    def ShowMSScan(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType, show: bool
    ) -> None: ...
    def DisplaySignal(self, signal: Signal) -> None: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def GetAvailableMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def HideSignal(self, signal: Signal) -> None: ...
    def GetSignalColor(self, signal: Signal) -> System.Drawing.Color: ...
    def InitializePanes(self) -> None: ...
    def GetDisplayedSignals(self) -> List[Signal]: ...
    def SearchLibrary(
        self, app: Agilent.MassHunter.Quantitative.UIModel.ILibraryApp
    ) -> None: ...

class SampleDataControl(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    Agilent.MassHunter.Quantitative.UIModel.ISampleDataPane,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    AutoScale: bool
    CanAutoScale: bool  # readonly
    CanCopy: bool  # readonly
    CanCreateTargetCompound: bool  # readonly
    CanCreateTargetQualifier: bool  # readonly
    CanExtractSpectrum: bool  # readonly
    CanFindComponents: bool  # readonly
    CanNormalizeEachX: bool  # readonly
    CanSearchLibrary: bool  # readonly
    HasSpectrumPanes: bool  # readonly
    MaxNumVisibleRows: int
    NormalizeType: NormalizeType
    OverlayAllSignals: bool
    OverlayIstdCompounds: bool
    OverlayTargetCompounds: bool
    PlotControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData.PlotControl
    )  # readonly
    SampleDataPath: str  # readonly
    ShowCurrentCompound: bool
    ShowTic: bool
    TimeRange: Agilent.MassSpectrometry.DataAnalysis.IRange  # readonly

    def StoreSettings(self) -> None: ...
    def GetActiveObject(self) -> T: ...
    def AutoScaleX(self) -> None: ...
    def ShowSpectrum(self, start: float, end: float) -> None: ...
    def GetMSScanColor(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Drawing.Color: ...
    def GetDisplayedMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def ShowComponents(
        self, components: Iterable[Agilent.MassSpectrometry.DataAnalysis.Component]
    ) -> None: ...
    def Copy(self) -> None: ...
    def GetAvailableSignals(self) -> List[Signal]: ...
    def CreateTargetCompound(self) -> None: ...
    def ClearSpectrumPanes(self) -> None: ...
    def CreatePropertyPages(self) -> List[IPropertyPage]: ...
    def CreateTargetQualifier(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def FindComponents(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Component
    ]: ...
    def ShowMSScan(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType, show: bool
    ) -> None: ...
    def DisplaySignal(self, signal: Signal) -> None: ...
    def GetAvailableMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def HideSignal(self, signal: Signal) -> None: ...
    def GetSignalColor(self, signal: Signal) -> System.Drawing.Color: ...
    def GetDisplayedSignals(self) -> List[Signal]: ...
    def SearchLibrary(
        self, app: Agilent.MassHunter.Quantitative.UIModel.ILibraryApp
    ) -> None: ...

class SampleInfoPropPage(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    IPropertyPage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(
        self,
        control: Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData.PlotControl,
    ) -> None: ...

class SampleInfoProperties:  # Class
    AutoScaleAfter: float
    BackColor: System.Drawing.Color
    ChromatogramPeakLabelCaption: bool
    ChromatogramPeakLabelTypes: List[ChromatogramPeakLabelType]
    ChromatogramPeakLabelUnits: bool
    ComponentColors: List[System.Drawing.Color]
    CompoundColors: List[System.Drawing.Color]
    CurrentCompoundColor: System.Drawing.Color
    FontSize: float
    ForeColor: System.Drawing.Color
    GridlinesColor: System.Drawing.Color
    GridlinesVisible: bool
    Normalize: bool
    OverlayAllMSScans: bool
    OverlayAllSignals: bool
    OverlayIstdCompounds: bool
    OverlayTargetCompounds: bool
    PeakLabelsAllowOverlap: bool
    PeakLabelsVertical: bool
    PrecursorColor: System.Drawing.Color
    PrecursorFill: bool
    PrecursorSize: int
    ShowCurrentCompound: bool
    ShowSignalLabels: bool
    ShowTic: bool
    SignalColors: List[System.Drawing.Color]
    SpectrumColor: System.Drawing.Color  # readonly
    TargetPeakLabelsOnTIC: bool
    TicColor: System.Drawing.Color
    TimeSegmentBorderColor: System.Drawing.Color
    TimeSegmentBorderVisible: bool

    def InitFromConfiguration(self) -> None: ...

class SelectMassEventManipulator(
    Agilent.MassSpectrometry.EventManipulating.EventManipulator,
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
):  # Class
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseDown(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ViewModel import (
    IControlPanelViewModel,
    IOutliersViewModel,
    ITask,
    TaskViewModelBase,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Outliers

class GroupHeaderConverter(System.Windows.Data.IValueConverter):  # Class
    def __init__(self) -> None: ...
    def ConvertBack(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...
    def Convert(
        self,
        value_: Any,
        targetType: System.Type,
        parameter: Any,
        culture: System.Globalization.CultureInfo,
    ) -> Any: ...

class OutlierItem(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.Outliers.OutliersViewModel,
        outlierColumns: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierColumns,
        category: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierCategories,
    ) -> None: ...

    VisibleProperty: System.Windows.DependencyProperty  # static

    DisplayName: str  # readonly
    OutlierCategory: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierCategories
    )  # readonly
    OutlierColumn: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierColumns
    )  # readonly
    Visible: bool

class OutliersView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class OutliersViewModel(TaskViewModelBase, IOutliersViewModel, ITask):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    OutlierItemsProperty: System.Windows.DependencyProperty  # static

    CommandCheckAll: System.Windows.Input.ICommand  # readonly
    CommandUncheckAll: System.Windows.Input.ICommand  # readonly
    Content: System.Windows.UIElement  # readonly
    Initializing: bool  # readonly
    IsEnabled: bool  # readonly
    OutlierItems: System.Windows.Data.ListCollectionView
    Title: str  # readonly
    View: Agilent.MassHunter.Quantitative.Startup.Edit.Outliers.OutliersView  # readonly

    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def IsDirty(self) -> bool: ...
    def SetOutliers(
        self, outliers: Agilent.MassHunter.Quantitative.Startup.Common.Outliers
    ) -> None: ...
    def Activate(self) -> None: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Controls.SplashScreen

class RUOWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class SplashScreenClassicWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def InitializeComponent(self) -> None: ...

class SplashScreenModel(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    ApplicationProperty: System.Windows.DependencyProperty  # static
    BuildTextProperty: System.Windows.DependencyProperty  # static
    CloseButtonVisibleProperty: System.Windows.DependencyProperty  # static
    CopyrightProperty: System.Windows.DependencyProperty  # static
    HasPCDLWarningProperty: System.Windows.DependencyProperty  # static
    IconProperty: System.Windows.DependencyProperty  # static
    QuantAppName: str = ...  # static # readonly
    RUOLinkVisibilityProperty: System.Windows.DependencyProperty  # static
    ShowInTaskbarProperty: System.Windows.DependencyProperty  # static
    SubAppProperty: System.Windows.DependencyProperty  # static
    TrialProperty: System.Windows.DependencyProperty  # static
    VersionTextProperty: System.Windows.DependencyProperty  # static

    Application: str
    Build: str
    BuildText: str
    CloseButtonVisible: bool
    Copyright: str
    Handle: System.IntPtr  # readonly
    HasPCDLWarning: bool
    Icon: System.Windows.Media.ImageSource
    Minimum: System.TimeSpan
    RUOLinkVisibility: System.Windows.Visibility
    ServicePack: str
    ShowInTaskbar: bool
    SubApp: str
    Trial: str
    Version: str
    VersionText: str

    @overload
    def SetOwner(self, owner: System.Windows.Window) -> None: ...
    @overload
    def SetOwner(self, ptr: System.IntPtr) -> None: ...
    def InitCompliance(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def ShowMessageBox(
        self,
        message: str,
        title: str,
        button: System.Windows.MessageBoxButton,
        image: System.Windows.MessageBoxImage,
    ) -> System.Windows.MessageBoxResult: ...
    @overload
    def Close(self, forceClose: bool) -> None: ...
    @overload
    def Close(self) -> None: ...
    def ShowDialog(self, parent: System.IntPtr) -> None: ...
    def Activate(self) -> None: ...
    def Show(self) -> None: ...
    def InitVersions(self) -> None: ...

class SplashScreenWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
